pub struct WorkerNode {
pub id: WorkerId,
pub type: i32,
pub host: Option<HostAddress>,
pub state: i32,
pub property: Option<Property>,
pub transactional_id: Option<u32>,
pub resource: Option<Resource>,
pub started_at: Option<u64>,
}Fields
id: WorkerIdtype: i32host: Option<HostAddress>state: i32property: Option<Property>transactional_id: Option<u32>Ranges from 0 to 1023, used to generate the machine ID field in the global unique ID.
resource: Option<Resource>Resource spec. It’s populated by meta node with the value reported by worker node and persisted in meta store.
started_at: Option<u64>Timestamp the worker node is added by meta node, in seconds. It’s populated by meta node, when the worker node is added by meta node. It’s persisted in meta store.
Implementations
Sourceimpl WorkerNode
impl WorkerNode
Sourcepub fn type(&self) -> WorkerType
pub fn type(&self) -> WorkerType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: WorkerType)
pub fn set_type(&mut self, value: WorkerType)
Sets type to the provided enum value.
Sourcepub fn state(&self) -> State
pub fn state(&self) -> State
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn transactional_id(&self) -> u32
pub fn transactional_id(&self) -> u32
Returns the value of transactional_id, or the default value if transactional_id is unset.
Sourcepub fn started_at(&self) -> u64
pub fn started_at(&self) -> u64
Returns the value of started_at, or the default value if started_at is unset.
Sourceimpl WorkerNode
impl WorkerNode
pub fn get_id(&self) -> WorkerId
pub fn get_type(&self) -> Result<WorkerType, PbFieldNotFound>
pub fn get_host(&self) -> Result<&HostAddress, PbFieldNotFound>
pub fn get_state(&self) -> Result<State, PbFieldNotFound>
pub fn get_property(&self) -> Result<&Property, PbFieldNotFound>
pub fn get_transactional_id(&self) -> Result<&u32, PbFieldNotFound>
pub fn get_resource(&self) -> Result<&Resource, PbFieldNotFound>
pub fn get_started_at(&self) -> Result<&u64, PbFieldNotFound>
Sourceimpl WorkerNode
impl WorkerNode
pub fn compute_node_parallelism(&self) -> usize
pub(crate) fn compactor_node_parallelism(&self) -> usize
pub fn parallelism(&self) -> Option<usize>
pub fn resource_group(&self) -> Option<String>