PbWorkerNode

Type Alias PbWorkerNode 

pub type PbWorkerNode = WorkerNode;

Aliased Type

pub struct PbWorkerNode {
    pub id: TypedId<6, u32>,
    pub type: i32,
    pub host: Option<HostAddress>,
    pub state: i32,
    pub property: Option<Property>,
    pub transactional_id: Option<u32>,
    pub resource: Option<Resource>,
    pub started_at: Option<u64>,
}

Fields

id: TypedId<6, u32>type: i32host: Option<HostAddress>state: i32property: Option<Property>transactional_id: Option<u32>

Ranges from 0 to 1023, used to generate the machine ID field in the global unique ID.

resource: Option<Resource>

Resource spec. It’s populated by meta node with the value reported by worker node and persisted in meta store.

started_at: Option<u64>

Timestamp the worker node is added by meta node, in seconds. It’s populated by meta node, when the worker node is added by meta node. It’s persisted in meta store.