pub enum Payload {
StreamChunkPayload(StreamChunkPayload),
StreamChunkRefPointer(i64),
}Variants
StreamChunkPayload(StreamChunkPayload)
StreamChunkRefPointer(i64)
This is a reference pointer to a StreamChunk. The StreamChunk is owned
by the JniSinkWriterStreamRequest, which should handle the release of StreamChunk.
Index set to 5 because 3 and 4 have been occupied by batch_id and epoch
Implementations
Sourceimpl Payload
impl Payload
Sourcepub fn merge(
field: &mut Option<Payload>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Payload>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.