pub enum Object {
TableId(TableId),
ViewId(ViewId),
SourceId(SourceId),
SinkId(SinkId),
FunctionId(FunctionId),
ConnectionId(ConnectionId),
SubscriptionId(SubscriptionId),
}Variants
TableId(TableId)
ViewId(ViewId)
SourceId(SourceId)
SinkId(SinkId)
FunctionId(FunctionId)
ConnectionId(ConnectionId)
SubscriptionId(SubscriptionId)
Implementations
Sourceimpl Object
impl Object
Sourcepub fn merge(
field: &mut Option<Object>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Object>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.