pub enum RexNode {
InputRef(u32),
Constant(Datum),
FuncCall(FunctionCall),
Udf(Box<UserDefinedFunction>),
Now(NowRexNode),
}Variants
Implementations
Sourceimpl RexNode
impl RexNode
Sourcepub fn merge(
field: &mut Option<RexNode>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<RexNode>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourceimpl RexNode
impl RexNode
Sourcepub fn is_input_ref(&self) -> bool
pub fn is_input_ref(&self) -> bool
Returns true if this is a RexNode::InputRef, otherwise false
Sourcepub fn as_input_ref_mut(&mut self) -> Option<&mut u32>
pub fn as_input_ref_mut(&mut self) -> Option<&mut u32>
Optionally returns mutable references to the inner fields if this is a RexNode::InputRef, otherwise None
Sourcepub fn as_input_ref(&self) -> Option<&u32>
pub fn as_input_ref(&self) -> Option<&u32>
Optionally returns references to the inner fields if this is a RexNode::InputRef, otherwise None
Sourcepub fn into_input_ref(self) -> Result<u32, Self>
pub fn into_input_ref(self) -> Result<u32, Self>
Returns the inner fields if this is a RexNode::InputRef, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_input_ref_unchecked(self) -> u32
pub unsafe fn into_input_ref_unchecked(self) -> u32
Unchecked return of the inner fields of RexNode::InputRef.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_input_ref_unchecked(&self) -> &u32
pub unsafe fn as_input_ref_unchecked(&self) -> &u32
Unchecked reference of the inner fields of RexNode::InputRef.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_input_ref_mut_unchecked(&mut self) -> &mut u32
pub unsafe fn as_input_ref_mut_unchecked(&mut self) -> &mut u32
Unchecked mutable reference of the inner fields of RexNode::InputRef.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub fn is_constant(&self) -> bool
pub fn is_constant(&self) -> bool
Returns true if this is a RexNode::Constant, otherwise false
Sourcepub fn as_constant_mut(&mut self) -> Option<&mut Datum>
pub fn as_constant_mut(&mut self) -> Option<&mut Datum>
Optionally returns mutable references to the inner fields if this is a RexNode::Constant, otherwise None
Sourcepub fn as_constant(&self) -> Option<&Datum>
pub fn as_constant(&self) -> Option<&Datum>
Optionally returns references to the inner fields if this is a RexNode::Constant, otherwise None
Sourcepub fn into_constant(self) -> Result<Datum, Self>
pub fn into_constant(self) -> Result<Datum, Self>
Returns the inner fields if this is a RexNode::Constant, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_constant_unchecked(self) -> Datum
pub unsafe fn into_constant_unchecked(self) -> Datum
Unchecked return of the inner fields of RexNode::Constant.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_constant_unchecked(&self) -> &Datum
pub unsafe fn as_constant_unchecked(&self) -> &Datum
Unchecked reference of the inner fields of RexNode::Constant.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_constant_mut_unchecked(&mut self) -> &mut Datum
pub unsafe fn as_constant_mut_unchecked(&mut self) -> &mut Datum
Unchecked mutable reference of the inner fields of RexNode::Constant.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub fn is_func_call(&self) -> bool
pub fn is_func_call(&self) -> bool
Returns true if this is a RexNode::FuncCall, otherwise false
Sourcepub fn as_func_call_mut(&mut self) -> Option<&mut FunctionCall>
pub fn as_func_call_mut(&mut self) -> Option<&mut FunctionCall>
Optionally returns mutable references to the inner fields if this is a RexNode::FuncCall, otherwise None
Sourcepub fn as_func_call(&self) -> Option<&FunctionCall>
pub fn as_func_call(&self) -> Option<&FunctionCall>
Optionally returns references to the inner fields if this is a RexNode::FuncCall, otherwise None
Sourcepub fn into_func_call(self) -> Result<FunctionCall, Self>
pub fn into_func_call(self) -> Result<FunctionCall, Self>
Returns the inner fields if this is a RexNode::FuncCall, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_func_call_unchecked(self) -> FunctionCall
pub unsafe fn into_func_call_unchecked(self) -> FunctionCall
Unchecked return of the inner fields of RexNode::FuncCall.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_func_call_unchecked(&self) -> &FunctionCall
pub unsafe fn as_func_call_unchecked(&self) -> &FunctionCall
Unchecked reference of the inner fields of RexNode::FuncCall.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_func_call_mut_unchecked(&mut self) -> &mut FunctionCall
pub unsafe fn as_func_call_mut_unchecked(&mut self) -> &mut FunctionCall
Unchecked mutable reference of the inner fields of RexNode::FuncCall.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub fn as_udf_mut(&mut self) -> Option<&mut Box<UserDefinedFunction>>
pub fn as_udf_mut(&mut self) -> Option<&mut Box<UserDefinedFunction>>
Optionally returns mutable references to the inner fields if this is a RexNode::Udf, otherwise None
Sourcepub fn as_udf(&self) -> Option<&Box<UserDefinedFunction>>
pub fn as_udf(&self) -> Option<&Box<UserDefinedFunction>>
Optionally returns references to the inner fields if this is a RexNode::Udf, otherwise None
Sourcepub fn into_udf(self) -> Result<Box<UserDefinedFunction>, Self>
pub fn into_udf(self) -> Result<Box<UserDefinedFunction>, Self>
Returns the inner fields if this is a RexNode::Udf, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_udf_unchecked(self) -> Box<UserDefinedFunction>
pub unsafe fn into_udf_unchecked(self) -> Box<UserDefinedFunction>
Unchecked return of the inner fields of RexNode::Udf.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_udf_unchecked(&self) -> &Box<UserDefinedFunction>
pub unsafe fn as_udf_unchecked(&self) -> &Box<UserDefinedFunction>
Unchecked reference of the inner fields of RexNode::Udf.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_udf_mut_unchecked(&mut self) -> &mut Box<UserDefinedFunction>
pub unsafe fn as_udf_mut_unchecked(&mut self) -> &mut Box<UserDefinedFunction>
Unchecked mutable reference of the inner fields of RexNode::Udf.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub fn as_now_mut(&mut self) -> Option<&mut NowRexNode>
pub fn as_now_mut(&mut self) -> Option<&mut NowRexNode>
Optionally returns mutable references to the inner fields if this is a RexNode::Now, otherwise None
Sourcepub fn as_now(&self) -> Option<&NowRexNode>
pub fn as_now(&self) -> Option<&NowRexNode>
Optionally returns references to the inner fields if this is a RexNode::Now, otherwise None
Sourcepub fn into_now(self) -> Result<NowRexNode, Self>
pub fn into_now(self) -> Result<NowRexNode, Self>
Returns the inner fields if this is a RexNode::Now, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_now_unchecked(self) -> NowRexNode
pub unsafe fn into_now_unchecked(self) -> NowRexNode
Unchecked return of the inner fields of RexNode::Now.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_now_unchecked(&self) -> &NowRexNode
pub unsafe fn as_now_unchecked(&self) -> &NowRexNode
Unchecked reference of the inner fields of RexNode::Now.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_now_mut_unchecked(&mut self) -> &mut NowRexNode
pub unsafe fn as_now_mut_unchecked(&mut self) -> &mut NowRexNode
Unchecked mutable reference of the inner fields of RexNode::Now.
Safety
Results in undefined behavior when it is the incorrect variant.