#[repr(i32)]pub enum CheckpointCompressionAlgorithm {
CheckpointCompressionUnspecified = 0,
CheckpointCompressionZstd = 1,
CheckpointCompressionLz4 = 2,
}Expand description
Compression algorithm used for checkpoint data serialization.
Variants
CheckpointCompressionUnspecified = 0
No compression (uncompressed).
CheckpointCompressionZstd = 1
Zstd compression (default, good balance between ratio and speed).
CheckpointCompressionLz4 = 2
Lz4 compression (faster but lower compression ratio).
Implementations
Sourceimpl CheckpointCompressionAlgorithm
impl CheckpointCompressionAlgorithm
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of CheckpointCompressionAlgorithm.
Sourcepub fn from_i32(value: i32) -> Option<CheckpointCompressionAlgorithm>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CheckpointCompressionAlgorithm>
Converts an i32 to a CheckpointCompressionAlgorithm, or None if value is not a valid variant.
Sourceimpl CheckpointCompressionAlgorithm
impl CheckpointCompressionAlgorithm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.