#[repr(i32)]pub enum SstableFilterLayout {
Unspecified = 0,
Auto = 1,
Plain = 2,
}Expand description
Layout strategy of the xor filter stored in SST.
Note: the actual on-disk encoding is still determined by the filter bytes footer. This enum is used for task planning and configuration.
Variants
Unspecified = 0
Auto = 1
Let the system decide whether to use a block-based filter (currently by kv-count threshold).
Plain = 2
Always use a single non-blocked filter. Ignore kv-count threshold.
Implementations
Sourceimpl SstableFilterLayout
impl SstableFilterLayout
Sourcepub fn from_i32(value: i32) -> Option<SstableFilterLayout>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SstableFilterLayout>
Converts an i32 to a SstableFilterLayout, or None if value is not a valid variant.
Sourceimpl SstableFilterLayout
impl SstableFilterLayout
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.