pub enum MutableConfig {
Show 30 variants
MaxBytesForLevelBase(u64),
MaxBytesForLevelMultiplier(u64),
MaxCompactionBytes(u64),
SubLevelMaxCompactionBytes(u64),
Level0TierCompactFileNumber(u64),
TargetFileSizeBase(u64),
CompactionFilterMask(u32),
MaxSubCompaction(u32),
Level0StopWriteThresholdSubLevelNumber(u64),
Level0SubLevelCompactLevelCount(u32),
Level0OverlappingSubLevelCompactLevelCount(u32),
MaxSpaceReclaimBytes(u64),
Level0MaxCompactFileNumber(u64),
EnableEmergencyPicker(bool),
TombstoneReclaimRatio(u32),
CompressionAlgorithm(CompressionAlgorithm),
MaxL0CompactLevelCount(u32),
SstAllowedTrivialMoveMinSize(u64),
SplitWeightByVnode(u32),
DisableAutoGroupScheduling(bool),
MaxOverlappingLevelSize(u64),
EmergencyLevel0SstFileCount(u32),
EmergencyLevel0SubLevelPartition(u32),
Level0StopWriteThresholdMaxSstCount(u32),
Level0StopWriteThresholdMaxSize(u64),
SstAllowedTrivialMoveMaxCount(u32),
EnableOptimizeL0IntervalSelection(bool),
VnodeAlignedLevelSizeThreshold(u64),
MaxKvCountForXor16(u64),
MaxVnodeKeyRangeBytes(u64),
}Variants
MaxBytesForLevelBase(u64)
MaxBytesForLevelMultiplier(u64)
MaxCompactionBytes(u64)
SubLevelMaxCompactionBytes(u64)
Level0TierCompactFileNumber(u64)
TargetFileSizeBase(u64)
CompactionFilterMask(u32)
MaxSubCompaction(u32)
Level0StopWriteThresholdSubLevelNumber(u64)
Level0SubLevelCompactLevelCount(u32)
Level0OverlappingSubLevelCompactLevelCount(u32)
MaxSpaceReclaimBytes(u64)
Level0MaxCompactFileNumber(u64)
EnableEmergencyPicker(bool)
TombstoneReclaimRatio(u32)
CompressionAlgorithm(CompressionAlgorithm)
MaxL0CompactLevelCount(u32)
SstAllowedTrivialMoveMinSize(u64)
SplitWeightByVnode(u32)
DisableAutoGroupScheduling(bool)
MaxOverlappingLevelSize(u64)
EmergencyLevel0SstFileCount(u32)
The emergency compaction limitations for the level0 sstables file count
EmergencyLevel0SubLevelPartition(u32)
The emergency compaction limitations for the level0 sub level partition
Level0StopWriteThresholdMaxSstCount(u32)
The limitation of the max sst size of the level0 to trigger the write stop
Level0StopWriteThresholdMaxSize(u64)
The limitation of the max sst size of the level0 to trigger the write stop
SstAllowedTrivialMoveMaxCount(u32)
The limitation of the max sst count of the trivial move task
EnableOptimizeL0IntervalSelection(bool)
Enable the optimization of the interval selection for the level0 compaction
VnodeAlignedLevelSizeThreshold(u64)
Deprecated. Kept for backward compatibility and ignored by meta.
MaxKvCountForXor16(u64)
The maximum key-value count threshold for using Xor16 filter
MaxVnodeKeyRangeBytes(u64)
Max bytes for vnode key-range hints recorded into each SST.
Implementations
Sourceimpl MutableConfig
impl MutableConfig
Sourcepub fn merge(
field: &mut Option<MutableConfig>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<MutableConfig>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.