pub struct SstableInfo {Show 17 fields
pub object_id: HummockSstableObjectId,
pub sst_id: HummockSstableId,
pub key_range: Option<KeyRange>,
pub file_size: u64,
pub table_ids: Vec<TableId>,
pub meta_offset: u64,
pub stale_key_count: u64,
pub total_key_count: u64,
pub min_epoch: u64,
pub max_epoch: u64,
pub uncompressed_file_size: u64,
pub range_tombstone_count: u64,
pub bloom_filter_kind: i32,
pub sst_size: u64,
pub vnode_statistics: Option<VnodeStatistics>,
pub filter_type: Option<i32>,
pub filter_layout: Option<i32>,
}Fields
object_id: HummockSstableObjectIdsst_id: HummockSstableIdkey_range: Option<KeyRange>file_size: u64represents the physical object size, which is usually used in the builder.
table_ids: Vec<TableId>meta_offset: u64stale_key_count: u64total_key_count: u64min_epoch: u64max_epoch: u64uncompressed_file_size: u64range_tombstone_count: u64bloom_filter_kind: i32Legacy SST filter metadata for SSTs written before filter_type and filter_layout existed.
New writers must leave this field as BLOOM_FILTER_UNSPECIFIED and set filter_type instead.
sst_size: u64In order to calculate more finely in the compaction strategy, we need to re-calculate the sst_size after split sst
sst_size represents the size of the sst instead of the object size(usually used in the meta).
vnode_statistics: Option<VnodeStatistics>Optional per-vnode statistics for query pruning when the SST spans only a small set of vnodes. Only emitted when SST contains multiple vnodes to avoid redundancy with key_range.
filter_type: Option<i32>Canonical SST filter type for newly written SSTs. If this field is present,
bloom_filter_kind must be BLOOM_FILTER_UNSPECIFIED.
filter_layout: Option<i32>Canonical SST filter physical layout for newly written SSTs. This is set only when
filter_type is not SSTABLE_FILTER_NONE.
Implementations
Sourceimpl SstableInfo
impl SstableInfo
Sourcepub fn bloom_filter_kind(&self) -> BloomFilterType
pub fn bloom_filter_kind(&self) -> BloomFilterType
Returns the enum value of bloom_filter_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_bloom_filter_kind(&mut self, value: BloomFilterType)
pub fn set_bloom_filter_kind(&mut self, value: BloomFilterType)
Sets bloom_filter_kind to the provided enum value.
Sourcepub fn filter_type(&self) -> SstableFilterType
pub fn filter_type(&self) -> SstableFilterType
Returns the enum value of filter_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_filter_type(&mut self, value: SstableFilterType)
pub fn set_filter_type(&mut self, value: SstableFilterType)
Sets filter_type to the provided enum value.
Sourcepub fn filter_layout(&self) -> SstableFilterLayout
pub fn filter_layout(&self) -> SstableFilterLayout
Returns the enum value of filter_layout, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_filter_layout(&mut self, value: SstableFilterLayout)
pub fn set_filter_layout(&mut self, value: SstableFilterLayout)
Sets filter_layout to the provided enum value.
Sourceimpl SstableInfo
impl SstableInfo
pub fn get_object_id(&self) -> HummockSstableObjectId
pub fn get_sst_id(&self) -> HummockSstableId
pub fn get_key_range(&self) -> Result<&KeyRange, PbFieldNotFound>
pub fn get_file_size(&self) -> u64
pub fn get_table_ids(&self) -> &Vec<TableId> ⓘ
pub fn get_meta_offset(&self) -> u64
pub fn get_stale_key_count(&self) -> u64
pub fn get_total_key_count(&self) -> u64
pub fn get_min_epoch(&self) -> u64
pub fn get_max_epoch(&self) -> u64
pub fn get_uncompressed_file_size(&self) -> u64
pub fn get_range_tombstone_count(&self) -> u64
pub fn get_bloom_filter_kind(&self) -> Result<BloomFilterType, PbFieldNotFound>
pub fn get_sst_size(&self) -> u64
pub fn get_vnode_statistics(&self) -> Result<&VnodeStatistics, PbFieldNotFound>
pub fn get_filter_type(&self) -> Result<&i32, PbFieldNotFound>
pub fn get_filter_layout(&self) -> Result<&i32, PbFieldNotFound>