PbCompactTask

Type Alias PbCompactTask 

pub type PbCompactTask = CompactTask;

Aliased Type

pub struct PbCompactTask {
Show 28 fields pub input_ssts: Vec<InputLevel>, pub splits: Vec<KeyRange>, pub sorted_output_ssts: Vec<SstableInfo>, pub task_id: u64, pub target_level: u32, pub gc_delete_keys: bool, pub base_level: u32, pub task_status: i32, pub compaction_group_id: TypedId<10, u64>, pub existing_table_ids: Vec<TypedId<0, u32>>, pub compression_algorithm: u32, pub target_file_size: u64, pub compaction_filter_mask: u32, pub table_options: BTreeMap<TypedId<0, u32>, TableOption>, pub current_epoch_time: u64, pub target_sub_level_id: u64, pub task_type: i32, pub split_by_state_table: bool, pub split_weight_by_vnode: u32, pub table_vnode_partition: BTreeMap<TypedId<0, u32>, u32>, pub table_watermarks: BTreeMap<TypedId<0, u32>, TableWatermarks>, pub table_schemas: BTreeMap<TypedId<0, u32>, TableSchema>, pub max_sub_compaction: u32, pub compaction_group_version_id: u64, pub max_kv_count_for_xor16: Option<u64>, pub max_vnode_key_range_bytes: Option<u64>, pub sstable_filter_kind: i32, pub sstable_filter_layout: i32,
}

Fields

input_ssts: Vec<InputLevel>

SSTs to be compacted, which will be removed from LSM after compaction

splits: Vec<KeyRange>

In ideal case, the compaction will generate splits.len() tables which have key range corresponding to that in [splits], respectively

sorted_output_ssts: Vec<SstableInfo>

compaction output, which will be added to [target_level] of LSM after compaction

task_id: u64

task id assigned by hummock storage service

target_level: u32

compaction output will be added to [target_level] of LSM after compaction

gc_delete_keys: boolbase_level: u32

Lbase in LSM

task_status: i32compaction_group_id: TypedId<10, u64>

compaction group the task belongs to

existing_table_ids: Vec<TypedId<0, u32>>

existing_table_ids for compaction drop key

compression_algorithm: u32target_file_size: u64compaction_filter_mask: u32table_options: BTreeMap<TypedId<0, u32>, TableOption>current_epoch_time: u64target_sub_level_id: u64task_type: i32

Identifies whether the task is space_reclaim, if the compact_task_type increases, it will be refactored to enum

split_by_state_table: bool
👎Deprecated

Deprecated. use table_vnode_partition instead;

split_weight_by_vnode: u32

Compaction needs to cut the state table every time 1/weight of vnodes in the table have been processed. Deprecated. use table_vnode_partition instead;

table_vnode_partition: BTreeMap<TypedId<0, u32>, u32>table_watermarks: BTreeMap<TypedId<0, u32>, TableWatermarks>

The table watermark of any table id. In compaction we only use the table watermarks on safe epoch, so we only need to include the table watermarks on safe epoch to reduce the size of metadata.

table_schemas: BTreeMap<TypedId<0, u32>, TableSchema>

The table schemas that are at least as new as the one used to create input_ssts.

max_sub_compaction: u32

Max sub compaction task numbers

compaction_group_version_id: u64

The compaction group id when the compaction task is created.

max_kv_count_for_xor16: Option<u64>

KV-count threshold for using blocked xor filter when sstable_filter_layout is AUTO.

If the estimated key count of one output SST exceeds this threshold, compaction will build blocked xor filters. Otherwise it will build a single non-blocked xor filter.

This is an output-SST-level heuristic. Older versions compared the threshold with the total key count of the whole compaction task, which could classify many small output SSTs as blocked.

Keep the historical protobuf field name for wire and JSON compatibility.

max_vnode_key_range_bytes: Option<u64>

Max bytes for vnode-level key range hints to embed into output SSTs.

sstable_filter_kind: i32

The xor filter family that output SSTs in this task should use.

sstable_filter_layout: i32

The xor filter layout to use for output SSTs in this task.