PbSstableInfo

Type Alias PbSstableInfo 

pub type PbSstableInfo = SstableInfo;

Aliased Type

pub struct PbSstableInfo {
Show 17 fields pub object_id: TypedId<5, u64>, pub sst_id: TypedId<6, u64>, pub key_range: Option<KeyRange>, pub file_size: u64, pub table_ids: Vec<TypedId<0, u32>>, pub meta_offset: u64, pub stale_key_count: u64, pub total_key_count: u64, pub min_epoch: u64, pub max_epoch: u64, pub uncompressed_file_size: u64, pub range_tombstone_count: u64, pub bloom_filter_kind: i32, pub sst_size: u64, pub vnode_statistics: Option<VnodeStatistics>, pub filter_type: Option<i32>, pub filter_layout: Option<i32>,
}

Fields

object_id: TypedId<5, u64>sst_id: TypedId<6, u64>key_range: Option<KeyRange>file_size: u64

represents the physical object size, which is usually used in the builder.

table_ids: Vec<TypedId<0, u32>>meta_offset: u64stale_key_count: u64total_key_count: u64min_epoch: u64max_epoch: u64uncompressed_file_size: u64range_tombstone_count: u64bloom_filter_kind: i32
👎Deprecated

Legacy SST filter metadata for SSTs written before filter_type and filter_layout existed. New writers must leave this field as BLOOM_FILTER_UNSPECIFIED and set filter_type instead.

sst_size: u64

In order to calculate more finely in the compaction strategy, we need to re-calculate the sst_size after split sst sst_size represents the size of the sst instead of the object size(usually used in the meta).

vnode_statistics: Option<VnodeStatistics>

Optional per-vnode statistics for query pruning when the SST spans only a small set of vnodes. Only emitted when SST contains multiple vnodes to avoid redundancy with key_range.

filter_type: Option<i32>

Canonical SST filter type for newly written SSTs. If this field is present, bloom_filter_kind must be BLOOM_FILTER_UNSPECIFIED.

filter_layout: Option<i32>

Canonical SST filter physical layout for newly written SSTs. This is set only when filter_type is not SSTABLE_FILTER_NONE.