pub enum ObjectInfo {
Database(Database),
Schema(Schema),
Table(Table),
Index(Index),
Source(Source),
Sink(Sink),
View(View),
Function(Function),
Connection(Connection),
Subscription(Subscription),
Secret(Secret),
}Variants
Database(Database)
Schema(Schema)
Table(Table)
Index(Index)
Source(Source)
Sink(Sink)
View(View)
Function(Function)
Connection(Connection)
Subscription(Subscription)
Secret(Secret)
Implementations
Sourceimpl ObjectInfo
impl ObjectInfo
Sourcepub fn merge(
field: &mut Option<ObjectInfo>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<ObjectInfo>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.