pub struct ClearFileCacheResponse {}Trait Implementations
Sourceimpl Clone for ClearFileCacheResponse
impl Clone for ClearFileCacheResponse
Sourcefn clone(&self) -> ClearFileCacheResponse
fn clone(&self) -> ClearFileCacheResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ClearFileCacheResponse
Sourceimpl Debug for ClearFileCacheResponse
impl Debug for ClearFileCacheResponse
Sourceimpl Default for ClearFileCacheResponse
impl Default for ClearFileCacheResponse
Sourceimpl<'de> Deserialize<'de> for ClearFileCacheResponse
impl<'de> Deserialize<'de> for ClearFileCacheResponse
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ClearFileCacheResponse
Sourceimpl Hash for ClearFileCacheResponse
impl Hash for ClearFileCacheResponse
Sourceimpl Message for ClearFileCacheResponse
impl Message for ClearFileCacheResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ClearFileCacheResponse
impl PartialEq for ClearFileCacheResponse
Sourcefn eq(&self, other: &ClearFileCacheResponse) -> bool
fn eq(&self, other: &ClearFileCacheResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ClearFileCacheResponse
impl Serialize for ClearFileCacheResponse
impl StructuralPartialEq for ClearFileCacheResponse