pub struct GetMetaStoreInfoRequest {}Trait Implementations
Sourceimpl Clone for GetMetaStoreInfoRequest
impl Clone for GetMetaStoreInfoRequest
Sourcefn clone(&self) -> GetMetaStoreInfoRequest
fn clone(&self) -> GetMetaStoreInfoRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetMetaStoreInfoRequest
impl Debug for GetMetaStoreInfoRequest
Sourceimpl Default for GetMetaStoreInfoRequest
impl Default for GetMetaStoreInfoRequest
Sourceimpl<'de> Deserialize<'de> for GetMetaStoreInfoRequest
impl<'de> Deserialize<'de> for GetMetaStoreInfoRequest
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for GetMetaStoreInfoRequest
impl Hash for GetMetaStoreInfoRequest
Sourceimpl Message for GetMetaStoreInfoRequest
impl Message for GetMetaStoreInfoRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetMetaStoreInfoRequest
impl PartialEq for GetMetaStoreInfoRequest
Sourceimpl Serialize for GetMetaStoreInfoRequest
impl Serialize for GetMetaStoreInfoRequest
impl Copy for GetMetaStoreInfoRequest
impl Eq for GetMetaStoreInfoRequest
impl StructuralPartialEq for GetMetaStoreInfoRequest