pub struct TableCacheRefillPolicy {
pub table_id: u32,
pub policy: i32,
}Fields
table_id: u32policy: i32Implementations
Sourceimpl TableCacheRefillPolicy
impl TableCacheRefillPolicy
Sourcepub fn policy(&self) -> CacheRefillPolicy
pub fn policy(&self) -> CacheRefillPolicy
Returns the enum value of policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_policy(&mut self, value: CacheRefillPolicy)
pub fn set_policy(&mut self, value: CacheRefillPolicy)
Sets policy to the provided enum value.
Sourceimpl TableCacheRefillPolicy
impl TableCacheRefillPolicy
pub fn get_table_id(&self) -> u32
pub fn get_policy(&self) -> Result<CacheRefillPolicy, PbFieldNotFound>