#[repr(i32)]pub enum CacheRefillPolicy {
Unspecified = 0,
Enabled = 1,
Disabled = 2,
Streaming = 3,
Serving = 4,
Both = 5,
}Variants
Unspecified = 0
/ Unspecified policy, use global default configuration.
Enabled = 1
/ Enable normal cache refill for the table.
Disabled = 2
/ Disable cache refill for the table.
Streaming = 3
/ Enable cache refill optimized for streaming workloads for this table.
Serving = 4
/ Enable cache refill optimized for serving workloads for this table.
Both = 5
/ Enable cache refill optimized for both streaming and serving workloads for this table.
Implementations
Sourceimpl CacheRefillPolicy
impl CacheRefillPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.