pub struct Column {
pub pk_col_idx: u32,
pub comparison: i32,
}Fields
pk_col_idx: u32comparison: i32Implementations
Sourceimpl Column
impl Column
Sourcepub fn comparison(&self) -> Comparison
pub fn comparison(&self) -> Comparison
Returns the enum value of comparison, or the default if the field is set to an invalid enum value.
Sourcepub fn set_comparison(&mut self, value: Comparison)
pub fn set_comparison(&mut self, value: Comparison)
Sets comparison to the provided enum value.
Sourceimpl Column
impl Column
pub fn get_pk_col_idx(&self) -> u32
pub fn get_comparison(&self) -> Result<Comparison, PbFieldNotFound>