#[repr(i32)]pub enum JoinType {
Unspecified = 0,
Inner = 1,
LeftOuter = 2,
RightOuter = 3,
FullOuter = 4,
LeftSemi = 5,
LeftAnti = 6,
RightSemi = 7,
RightAnti = 8,
AsofInner = 9,
AsofLeftOuter = 10,
}Variants
Unspecified = 0
Note that it comes from Calcite’s JoinRelType. DO NOT HAVE direction for SEMI and ANTI now.
Inner = 1
LeftOuter = 2
RightOuter = 3
FullOuter = 4
LeftSemi = 5
LeftAnti = 6
RightSemi = 7
RightAnti = 8
AsofInner = 9
AsofLeftOuter = 10
Implementations
Sourceimpl JoinType
impl JoinType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.