pub enum Inner {
ValueState(ValueState),
MaterializedInputState(MaterializedInputState),
}Variants
ValueState(ValueState)
MaterializedInputState(MaterializedInputState)
Implementations
Sourceimpl Inner
impl Inner
Sourcepub fn merge(
field: &mut Option<Inner>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Inner>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.