#[repr(i32)]pub enum Kind {
Unspecified = 0,
Last = 1,
First = 2,
Classifier = 3,
CountStar = 4,
Count = 5,
Min = 6,
Max = 7,
Sum = 8,
}Variants
Unspecified = 0
Last = 1
LAST(var.col): column value of the last row labeled var in the match (also the meaning of
a bare var.col under ONE ROW PER MATCH FINAL semantics).
First = 2
FIRST(var.col): column value of the first such row.
Classifier = 3
CLASSIFIER(): the pattern variable bound to the match’s last row (var/col_idx unused).
CountStar = 4
COUNT(*): number of rows in the match (var/col_idx unused).
Count = 5
COUNT(var.col): number of rows labeled var whose col is non-null.
Min = 6
MIN(var.col) / MAX(var.col): min / max of col over rows labeled var.
Max = 7
Sum = 8
SUM(var.col): evaluated by agg_call over the rows labeled var. (AVG is lowered by the
planner into a SUM slot plus a COUNT slot and a division expression.)
Implementations
Sourceimpl Kind
impl Kind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.