pub struct MergeNode {
pub upstream_actor_id: Vec<u32>,
pub upstream_fragment_id: FragmentId,
pub upstream_dispatcher_type: i32,
pub fields: Vec<Field>,
pub allow_empty_upstream: bool,
}Fields
upstream_actor_id: Vec<u32>WARNING: Use this field with caution.
upstream_actor_id stored in the plan node in Fragment meta model cannot be directly used.
See compose_fragment.
The field is deprecated because the upstream actor info is provided separately instead of
injected here in the node.
upstream_fragment_id: FragmentIdupstream_dispatcher_type: i32Type of the upstream dispatcher. If there’s always one upstream according to this
type, the compute node may use the ReceiverExecutor as an optimization.
fields: Vec<Field>The schema of input columns. Already deprecated.
allow_empty_upstream: boolAllows this merge to have no upstream actors, either initially or after a MergeUpdate. When true, the merge must not use the singleton receiver optimization because a singleton receiver cannot transition to empty.
Implementations
Sourceimpl MergeNode
impl MergeNode
Sourcepub fn upstream_dispatcher_type(&self) -> DispatcherType
pub fn upstream_dispatcher_type(&self) -> DispatcherType
Returns the enum value of upstream_dispatcher_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_upstream_dispatcher_type(&mut self, value: DispatcherType)
pub fn set_upstream_dispatcher_type(&mut self, value: DispatcherType)
Sets upstream_dispatcher_type to the provided enum value.
Sourceimpl MergeNode
impl MergeNode
pub fn get_upstream_actor_id(&self) -> &Vec<u32>
pub fn get_upstream_fragment_id(&self) -> FragmentId
pub fn get_upstream_dispatcher_type( &self, ) -> Result<DispatcherType, PbFieldNotFound>
pub fn get_fields(&self) -> &Vec<Field>
pub fn get_allow_empty_upstream(&self) -> bool