PbMergeNode

Type Alias PbMergeNode 

pub type PbMergeNode = MergeNode;

Aliased Type

pub struct PbMergeNode {
    pub upstream_actor_id: Vec<u32>,
    pub upstream_fragment_id: TypedId<4, u32>,
    pub upstream_dispatcher_type: i32,
    pub fields: Vec<Field>,
    pub allow_empty_upstream: bool,
}

Fields

upstream_actor_id: Vec<u32>
👎Deprecated

WARNING: Use this field with caution.

upstream_actor_id stored in the plan node in Fragment meta model cannot be directly used. See compose_fragment. The field is deprecated because the upstream actor info is provided separately instead of injected here in the node.

upstream_fragment_id: TypedId<4, u32>upstream_dispatcher_type: i32

Type of the upstream dispatcher. If there’s always one upstream according to this type, the compute node may use the ReceiverExecutor as an optimization.

fields: Vec<Field>
👎Deprecated

The schema of input columns. Already deprecated.

allow_empty_upstream: bool

Allows this merge to have no upstream actors, either initially or after a MergeUpdate. When true, the merge must not use the singleton receiver optimization because a singleton receiver cannot transition to empty.