pub struct RefreshFinishedActor {
pub reporter_actor_id: ActorId,
pub table_id: TableId,
}Expand description
A materialize actor has finished its part of a table refresh. Once all materialize actors of the table have reported, meta finishes the refresh cycle.
Fields
reporter_actor_id: ActorIdtable_id: TableIdImplementations
Sourceimpl RefreshFinishedActor
impl RefreshFinishedActor
pub fn get_reporter_actor_id(&self) -> ActorId
pub fn get_table_id(&self) -> TableId