pub type PbIcebergCompactionTask = IcebergCompactionTask;Aliased Type
pub struct PbIcebergCompactionTask {
pub task_id: TypedId<11, u64>,
pub props: BTreeMap<String, String>,
pub task_type: i32,
pub sink_id: u32,
pub pk_index_coordinated: bool,
}Fields
task_id: TypedId<11, u64>props: BTreeMap<String, String>compactor will get the information of the iceberg table from the properties
task_type: i32sink_id: u32pk_index_coordinated: boolWhether this task should be routed through the meta-coordinated commit path for iceberg pk-index sinks, the compactor performs the rewrite without committing and reports the result back to meta instead.