pub type PbOverWindowNode = OverWindowNode;Aliased Type
pub struct PbOverWindowNode {
pub calls: Vec<WindowFunction>,
pub partition_by: Vec<u32>,
pub order_by: Vec<ColumnOrder>,
pub state_table: Option<Table>,
pub cache_policy: i32,
pub enable_state_cleaning: bool,
}Fields
calls: Vec<WindowFunction>partition_by: Vec<u32>order_by: Vec<ColumnOrder>state_table: Option<Table>cache_policy: i32👎Deprecated
Deprecated. Use the one from StreamingDeveloperConfig instead.
enable_state_cleaning: boolWhether the executor is allowed to clean up state rows in recently touched partitions that
can never be accessed again, driven by the watermark on the first order_by column. The
optimizer only enables this when the input is append-only, all window frames are bounded
ROWS frames, and the first order_by column is a watermark column.